# Leeger

Instant stats for your fantasy football league.

![Main Build](https://github.com/joeyagreco/leeger/actions/workflows/main-build.yml/badge.svg)
![Last Commit](https://img.shields.io/github/last-commit/joeyagreco/leeger)

## Supported Fantasy Sites
Sites that you can automatically load your league data from.

| Name            | Website                                   | Supported          |
|-----------------|-------------------------------------------|--------------------|
| ESPN            | https://www.espn.com/fantasy/football/    | :heavy_check_mark: |
| MyFantasyLeague | http://home.myfantasyleague.com/          | :x:                |
| NFL             | https://fantasy.nfl.com/                  | :x:                |
| Sleeper         | https://sleeper.com/fantasy-football      | :x:                |
| Yahoo           | https://football.fantasysports.yahoo.com/ | :heavy_check_mark: |

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install..

```bash
pip install leeger
```

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License

[MIT](https://choosealicense.com/licenses/mit/)